/* PrintAtree.java
 *
 * Jim McBeath, January 26, 1997
 */

package jimmc.roots;

/** Print an ancestor tree. */
class PrintAtree extends PrintFormat {
	public PrintAtree(CommandInterpreter ci){super(ci);}
	public String getName() {
		return "atree";
	}
	public RecordFormat getDefaultRecordFormat() {
		return new FormatOneLine(ci);
	}
	/** Print an ancestor tree of the first record in the list. */
	public void printRecords(PrintOptions po, RootsRecord ra[]) {
		if (ra==null || ra.length==0)
			return;
		printTree(po,"",true,ra[0],ra);
	}

	/** Recursive routine to print an atree.
	 * @param prefix the string to print in front of each output line
	 * @param above true if we are printing above our descendent
	 * @param p the record for the root of this tree section
	 * @param ra list of records to print; prune tree if not in this list
	 * @param rf the format to print each record in the tree
	 */
	private void printTree(PrintOptions po, String prefix,
			boolean above, RootsRecord p, RootsRecord ra[]) {
		RecordFormat rf = po.recordFormat;
		RootsRecord father = null;
		RootsRecord mother = null;
		RootsRecord ref[];
		ref = p.findReference("father");
		if (ref!=null && ref.length>0)
			father = ref[0];
		ref = p.findReference("mother");
		if (ref!=null && ref.length>0)
			mother = ref[0];
		String morePrefix;
		if (father!=null && RootsVector.Contains(ra,father)) {
			morePrefix = (prefix.length()>0&&!above)?"| ":"  ";
			printTree(po,prefix+morePrefix,true,father,ra);
		}
		if (prefix.length()>0)
			morePrefix = above?"/-":"\\-";
		else
			morePrefix = "+-";
		p.println(prefix+morePrefix+rf.formatRecord(po,p));
			/* use a single-line format, else indents fail */
		if (mother!=null && RootsVector.Contains(ra,mother)) {
			morePrefix = (prefix.length()>0&&above)?"| ":"  ";
			printTree(po,prefix+morePrefix,false,mother,ra);
		}
	}
}

/* end */
