/* PrintDtree.java
 *
 * Jim McBeath, January 26, 1997
 */

package jimmc.roots;

/** Print a descendent tree. */
class PrintDtree extends PrintFormat {
	public PrintDtree(CommandInterpreter ci){super(ci);}
	public String getName() {
		return "dtree";
	}
	public RecordFormat getDefaultRecordFormat() {
		return new FormatOneLine(ci);
	}
	/** Print a descendent tree of the first record in the list. */
	public void printRecords(PrintOptions po, RootsRecord ra[]) {
		if (ra==null || ra.length==0)
			return;
		printTree(po,ra,ra[0],0,0);
	}

	/** Recursive routine to print a dtree.
	 * @param po misc options
	 * @param ra list of records to print; prune tree if not in this list
	 * @param p the record to print
	 * @param indent number of generations indentation
	 * @param num the number of the child within the family
	 */
	private void printTree(PrintOptions po, RootsRecord ra[], 
				RootsRecord p, int indent, int num) {
		RecordFormat rf = po.recordFormat;
		p.println(prefix(indent,num)+rf.formatRecord(po,p));
			/* use a single-line format, else indents fail */
		/* Find the marriage records for this record */
		RootsRecord u[];
		if (p instanceof RootsUnion) {
			/* This is a marriage record, use it that way below. */
			u = new RootsRecord[1];
			u[0] = p;
		} else
			u = p.findReference("marriage");
		if (u==null)
			return;	/* no marriages, so no children */
		for (int m=0; m<u.length; m++) {
			String ss;
			RootsUnion uu = (RootsUnion)u[m];
			/* If husband, print wife, or vice versa;
			 * if p is a union record, print both h and w. */
			if (uu.husband!=null && uu.husband!=p) {
				ss = rf.formatRecord(po,uu.husband);
				if (ss!=null && !ss.trim().equals(""))
					p.println(prefix(indent,-1)+ss);
			}
			if (uu.wife!=null && uu.wife!=p) {
				ss = rf.formatRecord(po,uu.wife);
				if (ss!=null && !ss.trim().equals(""))
					p.println(prefix(indent,-1)+ss);
			}
			/* print the union record also */
			if (uu!=p) {
				ss = rf.formatRecord(po,uu);
				if (ss!=null && !ss.trim().equals(""))
					p.println(prefix(indent,-1)+ss);
			}
			/* Print the children of that union. */
			RootsRecord c[] = u[m].findReference("children");
			if (c==null)
				continue;	/* no children to print */
			for (int i=0; i<c.length; i++) {
				if (RootsVector.Contains(ra,c[i]))
					printTree(po,ra,c[i],indent+1,i);
			}
		}
	}
	private String prefix(int indent, int num) {
		StringBuffer sb = new StringBuffer();
		if (indent>0) {
			int numDots = 3*indent - 1;
			for (int i=0; i<numDots; i++)
				sb.append(".");
			sb.append(" ");
		}
		if (num<0)
			sb.append(" +");	/* indicate spouse */
		else
			sb.append(indent+1).append(".").append(num+1);
		sb.append(" ");
		return sb.toString();
	}
}

/* end */
