/* Copyright 1997 Jim McBeath
 *
 * Jim McBeath, January 12, 1997
 */

package jimmc.roots;

import java.io.*;

/** RootsSource gives information about a source of data used in the RootsBase.
 */

public class RootsSource extends RootsRecord {
	private String description;	/* the description of the source */

	public RootsSource(RootsBase base) {
		super(base);
	}

	public static RootsSource ParseNcvLines(RootsBase base, String lines[]){
		RootsSource r = new RootsSource(base);
		int n = 0;
		while (n<lines.length) {
			Ncv nv = new Ncv(lines,n);
			n += nv.numLines;
			r.addNcv(nv);
		}
		return r;
	}
	/* Returns true if we recognized the name and added the value */
	protected boolean addNcv(Ncv nv) {
		if (super.addNcv(nv))
			return true;
		else if (nv.name.equals("DESC"))
			description = nv.value;
		else
			return false;	/* not recognized */
		return true;		/* OK */
	}

	/* Find a list of sources */
	public static RootsSource[] FindRecordList(RootsBase base, String s) {
		RootsRecord ra[];
		ra = base.findRecordList(s);
		if (ra==null)
			return null;
		RootsSource a[] = new RootsSource[ra.length];
		for (int i=0; i<ra.length; i++) {
			a[i] = (RootsSource)(ra[i]);
		}
		return a;
	}

	/** Print out the type of a source record */
	public String formatNcvType() {
		return("T:R");
	}
	/** Print out the body of a source record */
	public void formatNcvBody(StringBuffer sb) {
		formatNcvItem(sb,"DESC",description);
		super.formatNcvBody(sb);
	}
	public String formatOneLine(PrintOptions po) {
		return "SOURCE:"+key+"(TBD)";
	}

	public RootsRecord[] findReference(String what) {
		if (what==null)
			return null;
		return super.findReference(what);
	}
	public void println(String s) {
		base.println(s);
	}
}

/* end */
