/* Copyright 1997 Jim McBeath
 *
 * Jim McBeath, January 21, 1997
 */

package jimmc.roots;

import java.util.Vector;

/** RootsVector simpifies building lists of RootsRecords. */
class RootsVector extends Vector {
	public RootsVector() {
		super();
	}

	/* Add an item to the vector.
	 * @param r record to add; ignored if null or already in the list
	 */
	public void add(RootsRecord r) {
		if (r==null)	/* don't add null */
			return;
		if (contains(r))	/* don't add duplicates */
			return;
		addElement(r);	/* put it in */
	}

	/** Add an array of records to the vector.
	 * @param ra array of records to add; calls add on each one.
	 */
	public void add(RootsRecord ra[]) {
		if (ra==null)	/* silently ignore null */
			return;
		for (int i=0; i<ra.length; i++)
			add(ra[i]);
	}

	/** Like elementAt, but already cast to RootsRecord. */
	public RootsRecord recordAt(int n) {
		return (RootsRecord)(elementAt(n));
	}

	/** Convert the vector into an array of records.
	 * @return array of records; null if no records
	 */
	public RootsRecord[] toRootsRecordArray() {
		if (size()==0)		/* nothing there */
			return null;
		RootsRecord ra[] = new RootsRecord[size()];
		copyInto(ra);
		return ra;
	}

	/** Combine two selection arrays and return the union of the two */
	public static RootsRecord[] Combine(RootsRecord a[], RootsRecord b[]){
		if (a==null)
			return b;	/* may be null */
		if (b==null)
			return a;
		RootsVector vr = new RootsVector();
		vr.add(a);
		vr.add(b);
		return vr.toRootsRecordArray();
	}

	/** Checks to see if an array contains a specified record.
	 * @param a the array in which to look
	 * @param r the record for which to search
	 * @return true if r is an element of a (and neither is null)
	 */
	public static boolean Contains(RootsRecord a[], RootsRecord r) {
		if (a==null || r==null)
			return false;
		for (int i=0; i<a.length; i++)
			if (a[i]!=null && a[i]==r)
				return true;
		return false;
	}

}

/* end */
