/* ScrolledTextWriter.java
 *
 * Jim McBeath, June 10, 1998
 */

package jimmc.roots;

import java.io.Writer;

/** This class directs Writer output to a ScrolledText window.
 */
public class ScrolledTextWriter extends Writer {
	/** Our output field. */
	protected ScrolledText scrolledText;

	/** Set up a writer for a ScrolledText field. */
	public ScrolledTextWriter(ScrolledText f) {
		scrolledText = f;
	}

	/** Nothing to do on a flush. */
	public void flush() {}

	/** Nothing to do on a close. */
	public void close() {}

	/** Write a char to the text field.
	 * @param b the char
	 */
	public void write(int b) {
		char[] cc = { (char)b };
		appendText(new String(cc));
	}

	/** Write a sub array of chars to the text field.
	 * @param b the data to be written
	 * @param off the start offset in the data
	 * @param len the number of chars to write
	 */
	public void write(char b[], int off, int len) {
		appendText(new String(b,off,len));
	}

	/** Write a substring to the text field.
	 * @param s the string to be written
	 * @param off the start offset in the string
	 * @param len the number of chars to write
	 */
	public void write(String s, int off, int len) {
		appendText(s.substring(off,off+len));
	}

	/** Append a string to the text field. */
	protected void appendText(String s) {
		scrolledText.append(s);
	}
}

/* end */
