/* ClassUtil.java
 *
 * Jim McBeath, October 6, 2001
 */

package jimmc.util;

/** Utility methods for dealing with Classes.
 */
public class ClassUtil {
	/** Create a new instance of a named class, verifying that it is
	 * a subclass of (or identical to) the given superclass.
	 * @param className The name of the class of the instance to create.
	 * @param superClass The reference class.
	 * @return An instance of className that can be cast to superClass.
	 */
	public static Object newInstance(String className, Class superClass) {
		Class cl;

		//Convert the class name to a Class object
		try {
			cl = Class.forName(className);
		} catch (ClassNotFoundException ex) {
			throw new MoreException(ex);
		}

		//Make sure the class is a subclass
		if (!superClass.isAssignableFrom(cl)) {
			//The given class name is not the right subclass
		}

		//Create and return an instance of that class
		try {
			return cl.newInstance();
		} catch (Exception ex) {
		   //InstantiationException, IllegalAccessException
			throw new MoreException(ex);
		}
	}
}

/* end */
